==> filemv0.43.zip: source/status.cpp <==

#include "defextern.h"


#ifndef STRICT
    #define STRICT
#endif
#include <stdio.h>
#include <windows.h>
#include "resource.h"
#include "myfilemv.h"
#include "main.h"
#include "status.h"
#include "paintflag.h"

char mes[MAX_PATH]="";

void settitle(HWND &hWnd)
{
	char *p=GetNPath();
	char *pf=GetNFile();
	if (p==NULL || pf==NULL) return;
	if(showpathTitle) wsprintf(title,"%s - %s / %s" ,&appname ,p ,pf );
	else wsprintf(title,"%s" ,&appname);
	SetWindowText(hWnd, title);
}

void settitle(HWND &hWnd, char *d)
{
	char *p=d;
	if (p==NULL ) return;
	if(showpathTitle) wsprintf(title,"%s - %s" ,&appname ,p );
	else wsprintf(title,"%s" ,&appname);
	SetWindowText(hWnd, title);
}

void resettitle(HWND &hWnd)
{
	settitle(hWnd);
}

void resettitle()
{
	settitle(hmainwnd);
}

void resettitle(char *d)
{
	settitle(hmainwnd, d);
}


void setstatusbyte(char *mes)
{
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)0 | 0, (LPARAM)mes);
}

void setstatusnum(DWORD num)
{
	wsprintf(mes,"%d",num);
	setstatus(mes);
}

void setstatusnum(int num,int all)
{
	wsprintf(mes,"%d/%d",num,all);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)0 | 0, (LPARAM)mes);
}

void setstatusspace(int num,int all, double space, double total)
{
	if(space<1000) sprintf(mes,"%d %.fMfree/%.fM", all, space,total);
	else sprintf(mes,"%d %10.2fGfree/%.2fG", all, space/1024,total/1024);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)0 | 0, (LPARAM)mes);
}



void setstatusonly(char *mes)
{
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)2 | 0, (LPARAM)mes);
}


void setstatusonly(int pos,char *mes)
{
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)pos | 0, (LPARAM)mes);
}

void setstatusfullpath(char *file)
{
	_fullpath(mes,file,MAX_PATH);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)2 | 0, (LPARAM)mes);
}


// logɂ

void setstatus(char *mes)
{
	if(mes==NULL) return;
	if(strlen(mes)==0) return;
	SYSTEMTIME st;
	char jikan[10];
	char form[]="%02d:%02d:%02d";

	GetLocalTime(&st);
	wsprintf(
		jikan,
		form,
	
		st.wHour,
		st.wMinute,
		st.wSecond
	);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)2 | 0, (LPARAM)mes);
	if(logflag) log<<jikan<<" "<<mes<<endl;//if(*log!=NULL) *
}


void setstatus(char *mes,char *m2)
{
	wsprintf(::mes,"%s %s", mes, m2);
	SendMessage(hStatus, SB_SETTEXT,
		(WPARAM)2 | 0, (LPARAM)::mes);
}



int Mes(char *m)
{
	return MessageBox(NULL, m, "E", MB_OK);
}
int Mes(int i)
{
	char *buffer=mes;
	wsprintf(buffer,"%d",i);
	return MessageBox(NULL, buffer, "E", MB_OK);
}

==> filemv0.47.zip: source/status.cpp <==

#include "defextern.h"


#ifndef STRICT
    #define STRICT
#endif
#include <stdio.h>
#include <windows.h>
#include "resource.h"
#include "myfilemv.h"
#include "main.h"
#include "status.h"
#include "paintflag.h"
#include "tab.h"

char mes[MAX_PATH]="";

void settitle(HWND &hWnd)
{
	int t=GetNTab();
	char *p=GetNPath();
	char *pf=GetNFile();
	if (p==NULL || pf==NULL) return;
	if(showpathTitle) 
	{
		if( t ==tab_l) wsprintf(title,"%s < %s / %s" ,&appname ,p ,pf );
		if( t ==tab_r) wsprintf(title,"%s > %s / %s" ,&appname ,p ,pf );
	}
	else wsprintf(title,"%s" ,&appname);
	SetWindowText(hWnd, title);
}

void settitle(HWND &hWnd, char *d, int tab)
{
	char *p=d;
	if (p==NULL ) return;
	if(showpathTitle) 
	{
		if( tab ==tab_l) wsprintf(title,"%s < %s" ,&appname ,p );
		if( tab ==tab_r) wsprintf(title,"%s > %s" ,&appname ,p );
	}
	else wsprintf(title,"%s" ,&appname);
	SetWindowText(hWnd, title);
}

void resettitle(HWND &hWnd)
{
	settitle(hWnd);
}

void resettitle()
{
	settitle(hmainwnd);
}

void resettitle(char *d, int tab)
{
	settitle(hmainwnd, d, tab);
}


void setstatusbyte(char *mes)
{
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)0 | 0, (LPARAM)mes);
}

void setstatusnum(DWORD num)
{
	wsprintf(mes,"%d",num);
	setstatus(mes);
}

void setstatusnum(int num,int all)
{
	wsprintf(mes,"%d/%d",num,all);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)0 | 0, (LPARAM)mes);
}

void setstatusspace(int num,int all, double space, double total)
{
	if(space<1000) sprintf(mes,"%d %.fMfree/%.fM", all, space,total);
	else sprintf(mes,"%d %10.2fGfree/%.2fG", all, space/1024,total/1024);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)0 | 0, (LPARAM)mes);
}



void setstatusonly(char *mes)
{
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)2 | 0, (LPARAM)mes);
}


void setstatusonly(int pos,char *mes)
{
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)pos | 0, (LPARAM)mes);
}

void setstatusfullpath(char *file)
{
	_fullpath(mes,file,MAX_PATH);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)2 | 0, (LPARAM)mes);
}


// logɂ

void setstatus(char *mes)
{
	if(mes==NULL) return;
	if(strlen(mes)==0) return;
	SYSTEMTIME st;
	char jikan[10];
	char form[]="%02d:%02d:%02d";

	GetLocalTime(&st);
	wsprintf(
		jikan,
		form,
	
		st.wHour,
		st.wMinute,
		st.wSecond
	);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)2 | 0, (LPARAM)mes);
	if(logflag) log<<jikan<<" "<<mes<<endl;//if(*log!=NULL) *
}

void setstatus(int i)
{
	wsprintf(mes,"%d",i);
	setstatus(mes);
}

void logwrite(char *str, char *str2)
{
	if(logflag) log<<str<<","<<str2<<endl;//if(*log!=NULL) *
}

void logwrite(short i, short j)
{
	if(logflag) log<<i<<","<<j<<endl;//if(*log!=NULL) *
}

void setstatus(char *mes,char *m2)
{
	wsprintf(::mes,"%s %s", mes, m2);
	SendMessage(hStatus, SB_SETTEXT,
		(WPARAM)2 | 0, (LPARAM)::mes);
}



int Mes(char *m)
{
	return MessageBox(NULL, m, "E", MB_OK);
}
int Mes(int i)
{
	char *buffer=mes;
	wsprintf(buffer,"%d",i);
	return MessageBox(NULL, buffer, "E", MB_OK);
}
